gchecky.controller.GcheckyError

Package gchecky :: Module controller :: Class GcheckyError |
[hide private]
[frames] | no frames]

# Class GcheckyError

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                                  GcheckyError

Known Subclasses:
  DataError, HandlerError, LibraryError, SystemError

Base class for exception that could be thrown by gchecky library.

Instance Methods | [hide private]
__init__(self, message, context, origin=None) @param message String message describing the problem. | source code
__unicode__(self) str(x) | source code
__str__(self) str(x) | source code
__repr__(self) str(x) | source code
Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__setattr__`, `__setstate__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, message, context, origin=None) (Constructor) | source code
    @param message String message describing the problem. Can't be empty.
    @param context An instance of gchecky.controller.ControllerContext
                   that describes the current request processing context.
                   Can't be None.
    @param origin The original exception that caused this exception
                  to be thrown if any. Could be None.
Overrides: exceptions.Exception.__init__

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: exceptions.BaseException.__str__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
str(x) Overrides: exceptions.BaseException.__repr__ (inherited documentation)